==> replicate_actions-8.x-1.2.tar.gz: replicate_actions/src/EventSubscriber/ReplicateSetNodeEdit.php <==
<?php

namespace Drupal\replicate_actions\EventSubscriber;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Url;
use Drupal\node\NodeInterface;
use Drupal\replicate\Events\AfterSaveEvent;
use Drupal\replicate\Events\ReplicateAlterEvent;
use Drupal\replicate\Events\ReplicatorEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Makes replicated nodes unpublished and redirect to edit mode.
 */
class ReplicateSetNodeEdit implements EventSubscriberInterface {

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $timeService;

  /**
   * ReplicateSetNodeEdit constructor.
   *
   * @param \Drupal\Component\Datetime\TimeInterface $time_service
   *   Current market report service.
   */
  public function __construct(TimeInterface $time_service) {
    $this->timeService = $time_service;
  }

  /**
   * Sets the status of a replicated node to unpublished.
   *
   * @param \Drupal\replicate\Events\ReplicateAlterEvent $event
   *   The event fired by the replicator.
   */
  public function setUnpublished(ReplicateAlterEvent $event) {
    $cloned_entity = $event->getEntity();

    if (!$cloned_entity instanceof NodeInterface) {
      return;
    }

    // We don't need to check if it's instanceof TranslatableInterface since
    // at this point it's guaranteed to be a node. If the above check changes
    // in the future, we would need to make sure this is translatable before
    // getting languages.
    foreach ($cloned_entity->getTranslationLanguages() as $translation_language) {
      /** @var \Drupal\node\NodeInterface $translation */
      $translation = $cloned_entity->getTranslation($translation_language->getId());
      $translation->setUnpublished();

      // Set correct created/ changed dates.
      $current_time = $this->timeService->getCurrentTime();
      $translation->setCreatedTime($current_time);
      $translation->setChangedTime($current_time);
    }
  }

  /**
   * Make a redirect to "edit" mode.
   *
   * @param \Drupal\replicate\Events\AfterSaveEvent $event
   *   The event fired by the replicator.
   */
  public function makeRedirect(AfterSaveEvent $event) {
    $cloned_entity = $event->getEntity();

    if (!$cloned_entity instanceof NodeInterface) {
      return;
    }

    $edit_form_url = Url::fromRoute('entity.node.edit_form', [
      'node' => $cloned_entity->id(),
    ]);
    $response = new RedirectResponse($edit_form_url->toString());
    $response->send();

  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events = [];
    $events[ReplicatorEvents::REPLICATE_ALTER][] = 'setUnpublished';
    $events[ReplicatorEvents::AFTER_SAVE][] = 'makeRedirect';

    return $events;
  }

}

==> replicate_actions-8.x-1.3.tar.gz: replicate_actions/src/EventSubscriber/ReplicateSetNodeEdit.php <==
<?php

namespace Drupal\replicate_actions\EventSubscriber;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Url;
use Drupal\node\NodeInterface;
use Drupal\replicate\Events\AfterSaveEvent;
use Drupal\replicate\Events\ReplicateAlterEvent;
use Drupal\replicate\Events\ReplicatorEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Makes replicated nodes unpublished and redirect to edit mode.
 */
class ReplicateSetNodeEdit implements EventSubscriberInterface {

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected TimeInterface $timeService;

  /**
   * ReplicateSetNodeEdit constructor.
   *
   * @param \Drupal\Component\Datetime\TimeInterface $time_service
   */
  public function __construct(TimeInterface $time_service) {
    $this->timeService = $time_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = [];
    $events[ReplicatorEvents::REPLICATE_ALTER][] = ['setUnpublished', 1];
    $events[ReplicatorEvents::AFTER_SAVE][] = ['makeRedirect', 1];

    return $events;
  }

  /**
   * Sets the status of a replicated node to unpublished.
   *
   * @param \Drupal\replicate\Events\ReplicateAlterEvent $event
   *   The event fired by the replicator.
   *
   * @return void
   */
  public function setUnpublished(ReplicateAlterEvent $event): void {
    $clonedEntity = $event->getEntity();

    if (!$clonedEntity instanceof NodeInterface) {
      return;
    }

    // We don't need to check if it's instanceof TranslatableInterface since
    // at this point it's guaranteed to be a node. If the above check changes
    // in the future, we would need to make sure this is translatable before
    // getting languages.
    foreach ($clonedEntity->getTranslationLanguages() as $translation_language) {
      /** @var \Drupal\node\NodeInterface $translation */
      $translation = $clonedEntity->getTranslation($translation_language->getId());
      $translation->setUnpublished();

      // Set correct created/changed dates.
      $current_time = $this->timeService->getCurrentTime();
      $translation->setCreatedTime($current_time);
      $translation->setChangedTime($current_time);
    }
  }

  /**
   * Make a redirect to "edit" mode.
   *
   * @param \Drupal\replicate\Events\AfterSaveEvent $event
   *   The event fired by the replicator.
   */
  public function makeRedirect(AfterSaveEvent $event) {
    $clonedEntity = $event->getEntity();

    if (!$clonedEntity instanceof NodeInterface) {
      return;
    }

    $edit_form_url = Url::fromRoute('entity.node.edit_form', [
      'node' => $clonedEntity->id(),
    ]);
    $response = new RedirectResponse($edit_form_url->toString());
    $response->send();
  }

}
